summaryrefslogtreecommitdiffstats
path: root/lib/interfaces/kdevplugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/interfaces/kdevplugin.h')
-rw-r--r--lib/interfaces/kdevplugin.h48
1 files changed, 24 insertions, 24 deletions
diff --git a/lib/interfaces/kdevplugin.h b/lib/interfaces/kdevplugin.h
index fa31d239..fed92e69 100644
--- a/lib/interfaces/kdevplugin.h
+++ b/lib/interfaces/kdevplugin.h
@@ -37,17 +37,17 @@ class TQDomElement;
/**
@file kdevplugin.h
-KDevelop plugin interface.
+TDevelop plugin interface.
*/
/**Current KDevelop plugin interface version. Interfaces declare plugin version to make sure
old source (or binary) incompatible plugins are not loaded. Increase this if
it is necessary that old plugins stop working.*/
-#define KDEVELOP_PLUGIN_VERSION 5
+#define TDEVELOP_PLUGIN_VERSION 5
/**
-The base class for all KDevelop plugins.
-Plugin is a component which is loaded into KDevelop shell at startup or by request.
+The base class for all TDevelop plugins.
+Plugin is a component which is loaded into TDevelop shell at startup or by request.
Each plugin should have corresponding .desktop file with a description.
.desktop file template looks like:
@code
@@ -58,15 +58,15 @@ Name=
GenericName=
Comment=
Icon=
-X-KDevelop-Plugin-Version=
-X-KDevelop-Plugin-Homepage=
-X-KDevelop-Plugin-BugsEmailAddress=
-X-KDevelop-Plugin-Copyright=
+X-TDevelop-Plugin-Version=
+X-TDevelop-Plugin-Homepage=
+X-TDevelop-Plugin-BugsEmailAddress=
+X-TDevelop-Plugin-Copyright=
X-TDE-Library=
-X-KDevelop-Version=
-X-KDevelop-Scope=
-X-KDevelop-Properties=
-X-KDevelop-Args=
+X-TDevelop-Version=
+X-TDevelop-Scope=
+X-TDevelop-Properties=
+X-TDevelop-Args=
@endcode
<b>Description of parameters in .desktop file:</b>
- <i>Name</i> is a non-translatable name of a plugin, it is used in KTrader queries
@@ -75,17 +75,17 @@ to search for a plugin (required);
plugin names in GUI (required);
- <i>Comment</i> is a short description about the plugin (optional);
- <i>Icon</i> is a plugin icon (preferred);
-- <i>X-KDevelop-Plugin-Version</i> is a version of a plugin (optional);
-- <i>X-KDevelop-Plugin-Homepage</i> is a home page of a plugin (optional);
-- <i>X-KDevelop-Plugin-License</i> is a license (optional). can be: GPL, LGPL, BSD, Artistic,
+- <i>X-TDevelop-Plugin-Version</i> is a version of a plugin (optional);
+- <i>X-TDevelop-Plugin-Homepage</i> is a home page of a plugin (optional);
+- <i>X-TDevelop-Plugin-License</i> is a license (optional). can be: GPL, LGPL, BSD, Artistic,
TQPL or Custom. If this property is not set, license is considered as unknown;
-- <i>X-KDevelop-Plugin-BugsEmailAddress</i> is an email address for bug reports (optional);
-- <i>X-KDevelop-Plugin-Copyright</i> is a copyright statement (optional);
+- <i>X-TDevelop-Plugin-BugsEmailAddress</i> is an email address for bug reports (optional);
+- <i>X-TDevelop-Plugin-Copyright</i> is a copyright statement (optional);
- <i>X-TDE-Library</i> is a name of library which contains the plugin (required);
-- <i>X-KDevelop-Version</i> is a version of KDevelop interfaces which is supported by the plugin (required);
-- <i>X-KDevelop-Scope</i> is a scope of a plugin (see below for explanation) (required);
-- <i>X-KDevelop-Args</i> is a list of additional arguments passed to plugins constructor (optional);
-- <i>X-KDevelop-Properties</i> is a list of properties which this plugin supports, see @ref Profile class documentation for explanation (required to work with shells that support profiles).
+- <i>X-TDevelop-Version</i> is a version of TDevelop interfaces which is supported by the plugin (required);
+- <i>X-TDevelop-Scope</i> is a scope of a plugin (see below for explanation) (required);
+- <i>X-TDevelop-Args</i> is a list of additional arguments passed to plugins constructor (optional);
+- <i>X-TDevelop-Properties</i> is a list of properties which this plugin supports, see @ref Profile class documentation for explanation (required to work with shells that support profiles).
.
Plugin scope can be either:
- Core
@@ -163,9 +163,9 @@ public:
Template argument is used as a type to cast the result to. This is done because extension
is usually derived from a certain base class and not directly from KDevPlugin.
- @param serviceType The service type of an extension (like "KDevelop/SourceFormatter").
+ @param serviceType The service type of an extension (like "TDevelop/SourceFormatter").
@param constraint The constraint which is applied when quering for the service. This
- constraint is a usual KTrader constraint statement (like "[X-KDevelop-Foo]=='MyFoo'").
+ constraint is a usual KTrader constraint statement (like "[X-TDevelop-Foo]=='MyFoo'").
@return A KDevelop extension plugin for given service type or 0 if no plugin supports it*/
template <class Extension>
Extension *extension(const TQString &serviceType, const TQString &constraint = "")
@@ -37,17 +37,17 @@ class TQDomElement;
*/
-/**Current KDevelop plugin interface version. Interfaces declare plugin version to make sure
+/**Current TDevelop plugin interface version. Interfaces declare plugin version to make sure
old source (or binary) incompatible plugins are not loaded. Increase this if
it is necessary that old plugins stop working.*/